======
xeauth
======


.. image:: https://img.shields.io/pypi/v/xeauth.svg
        :target: https://pypi.python.org/pypi/xeauth

.. image:: https://img.shields.io/travis/jmosbacher/xeauth.svg
        :target: https://travis-ci.com/jmosbacher/xeauth

.. image:: https://readthedocs.org/projects/xeauth/badge/?version=latest
        :target: https://xeauth.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Authentication client for the Xenon edark matter experiment.


* Free software: MIT
* Documentation: https://xeauth.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `briggySmalls/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`briggySmalls/cookiecutter-pypackage`: https://github.com/briggySmalls/cookiecutter-pypackage
